Skip to content

calculates 2nd generation bioenergy demand

Usage

calc2ndBioDem(datasource, rev = numeric_version("0.1"))

Arguments

datasource

source to be used

rev

data revision the output will be produced for (numeric_version)

Value

magpie object with results on country level, weight on country level, unit and description.

Examples

if (FALSE) { # \dontrun{
calcOutput("2ndBioDem")
} # }