Skip to content

This function aggregates the data from source SathayeForest. A weight is implemented as the mean for each MAgPIE region is calculated.

Usage

calcAfforestCosts()

Value

MAgPIE object of the calculated means of each MAgPIE region

Author

Nele Steinmetz

Examples


if (FALSE) { # \dontrun{

a <- calcOutput("AfforestCosts")

} # }