Skip to content

calculate the corrective balance flow that is needed because global production doesn't equal global supply

Usage

calcDomesticBalanceflow()

Value

List of magpie objects with results on country level, weight on country level, unit and description.

See also

[calcFAOmassbalance()]

Author

Benjamin Leon Bodirsky

Examples

if (FALSE) { # \dontrun{
calcOutput("DomesticBalanceflow")
} # }