Skip to content

Calculates the share of fruits and vegetables in the calorie supply from the others MAgPIE commodity for the past. Information on the calorie supply from fruits and vegetables is relevant in the context of dietary recommendations, e.g. as proposed by the EAT-Lancet Commission on healthy diets from sustainable food systems.

Usage

calcEATFruitvegRatio(populationweight = "PopulationPast")

Arguments

populationweight

datasource of populationweight: FAO can be selected in order to better meet exact values. Normal datasource is PopulationPast

Value

List of magpie objects with results on country level, weight on country level, unit and description.

Author

Isabelle Weindl, Felicitas Beier

Examples

if (FALSE) { # \dontrun{
calcOutput("EATFruitvegRatio")
} # }