Skip to content

Calculates minimum and maximum targets for healthy food intake according to reference recommendations proposed by the EAT-Lancet Commission on healthy diets from sustainable food systems, specified for different MAgPIE commodities.

Usage

calcEATLancetTargets(attributes = "kcal/d")

Arguments

attributes

Attributes of food commodities (available: kcal/d and g/d)

Value

List of magpie objects with results on country level, weight on country level, unit and description.

Author

Isabelle Weindl

Examples

if (FALSE) { # \dontrun{
calcOutput("EATLancetTargets")
} # }