Skip to content

Calculates which share of forest land is lost due to different drivers

Usage

calcForestLossShare()

Value

MAgPIE object with share of area lost in forests due to different drivers

Author

Abhijeet Mishra

Examples


if (FALSE) { # \dontrun{ 
calcOutput("ForestLossShare",aggregate=FALSE)
} # }