Skip to content

Calculates the management factor(s) needed to upscale the yield of forest plantations as compared to natural vegetation based on FAO data.

Usage

calcForestProductionInitialization()

Value

List of magpie objects with results on country level, weight on country level, unit and description.

Author

Abhijeet Mishra

Examples

if (FALSE) { # \dontrun{
calcOutput("ForestProductionInitialization")
} # }