R/calcForestryProductionRatio.R
calcForestryProductionRatio.Rd
Calculates the management factor(s) needed to upscale the yield of forest plantations as compared to natural vegetation based on FAO data.
calcForestryProductionRatio()
List of magpie objects with results on country level, weight on country level, unit and description.
calcFAOmassbalance_pre
Abhijeet Mishra
if (FALSE) { # \dontrun{ calcOutput("ForestryProductionRatio") } # }