Skip to content

This function calculates irrigation investment costs for each country until the year 2050. Values linearly converge towards the value of Germany (1995) by 2050.

Usage

calcIrrigationInvCosts()

Value

MAgPIE object

Author

Nele Steinmetz, Felicitas Beier

Examples

if (FALSE) { # \dontrun{
calcOutput("IrrigationInvCosts")
} # }