Skip to content

calculates the share of N in biomass derived from biological fixation

Usage

calcNitrogenFixationNdfa()

Value

List of magpie objects with results on country level, weight on country level, unit and description.

Author

Benjamin Leon Bodirsky

Examples

if (FALSE) { # \dontrun{
calcOutput("calcNitrogenFixationNdfa")
} # }