Skip to content

Provides pasture yields defined as ratio of grazed biomass to grazed area

Usage

calcPastureYield(range_pastr = FALSE)

Arguments

range_pastr

Boolean value indicating if the grass yields should be split between rangelands and pastures.

Value

Pasture yields and corresponding weights as a list of two MAgPIE objects

Author

Isabelle Weindl, Marcos Alves

Examples

if (FALSE) { # \dontrun{
calcOutput("PastureYield")
} # }