Skip to content

Calculates the interpolated contribution share of plantations to roundwood demand

Usage

calcPlantationContribution()

Value

List of magpie objects with results on country level, weight on country level, unit and description.

Author

Abhijeet Mishra

Examples

if (FALSE) { # \dontrun{
calcOutput("PlantationContribution")
} # }