Skip to content

Uses an exogenous trajectory of Soil organic matter loss nitrogen release

Usage

calcSOMexogenous()

Value

List of magpie objects with results on country level, weight on country level, unit and description.

See also

Author

Benjamin Leon Bodirsky

Examples

if (FALSE) { # \dontrun{
calcOutput("SOMexogenous")
} # }