Skip to content

Calculates historical trends in agricultural land use intensity Tau based on FAO yield trends.

Usage

calcTauHistorical()

Value

List of magpie objects with results on country level, weight on country level, unit and description.

Author

Isabelle Weindl

Examples


if (FALSE) { # \dontrun{ 
calcOutput("TauHistorical")
} # }