Skip to content

Calculate the difference between the global production and global domestic_supply (corrective balance flow). The difference is the result of imports not equaling exports, and because storage is not considered. The calculated DomesticBalanceflow assures that production matches domestic_supply. The goods come from nowhere and go to nowhere. The numbers are usually decreased linearly and become zero in 2050.

Usage

calcTradeBalanceflow()

Value

global domestic balanceflows as MAgPIE object

Author

Ulrich Kreidenweis, Xiaoxi Wang

Examples

if (FALSE) { # \dontrun{
a <- calcTradeBalanceflow()
} # }