Skip to content

Calculate export shares of countries compared to total export. This is based on export values from FAOSTAT. Function calculates this based on average values of the specified years.

Usage

calcTradeExportShr()

Value

export shares as MAgPIE object

Author

Ulrich Kreidenweis, Xiaoxi Wang

Examples

if (FALSE) { # \dontrun{
a <- calcTradeExportShr()
} # }