Skip to content

Data from Annex 4 of the following FAO study: FAO. 2011. Global food losses and food waste – Extent, causes and prevention. Rome (http://www.fao.org/3/a-i2697e.pdf)

Usage

readFAOLossesWaste(subtype)

Arguments

subtype

Steps of the food supply chain where food losses and waste occur. Available types are:

  • Consumption: consumption level

Value

magpie object of food waste percentages for several commodity groups

See also

Author

Isabelle Weindl

Examples


if (FALSE)  a <- readSource(type="FAOLossesWaste",subtype="Consumption")
 # \dontrun{}