Skip to content

Read in Half Earth data set containing conservation area for biodiversity protection based on the Half-Earth approach

Usage

readHalfEarth(subtype = "GLOBIO4")

Arguments

subtype

Data source to be read from

Value

MAgPIE object containing biodiveristy protection area at cellular level

Author

Felicitas Beier

Examples

if (FALSE) { # \dontrun{
readSource("HalfEarth", subtype = "GLOBIO4", convert = "onlycorrect")
} # }