Skip to content

read Ozone Yield Shock Data from the EAT-Lancet deepdive on Ozone shock effects on crop yields.

Usage

readOzoneYieldShock()

Value

MAgPIE object with country level yield shock data for year 2050.

Author

Jake Tommey

Examples

if (FALSE) { # \dontrun{
readSource("OzoneShock", convert = "onlycorrect")
} # }