Skip to content

Read in csv file containing coefficients of linear regression for the calculation of future pasture intensification dependent on animal numbers

Usage

readPYieldCoeff()

Value

MAgPIE object

See also

Author

Isabelle Weindl

Examples

if (FALSE) { # \dontrun{
a <- readSource("PYieldCoeff")
} # }