Skip to content

Read Share of timber predicted to come from plantations based on FAO Brown study

Usage

readTimberShare(subtype = "abare")

Arguments

subtype

Data subtype available is abare and brown

Value

magpie object of the proportion of production coming from plantations

See also

Author

Abhijeet Mishra

Examples


if (FALSE) { # \dontrun{
a <- readSource("TimberShare")
} # }