R/calc2ndBioDem.R
calc2ndBioDem.Rd
calculates 2nd generation bioenergy demand
calc2ndBioDem(datasource, rev = numeric_version("0.1"))
source to be used
data revision the output will be produced for (numeric_version)
magpie object with results on country level, weight on country level, unit and description.
if (FALSE) { # \dontrun{ calcOutput("2ndBioDem") } # }