Aggregation and calculation of the mean of each MAgPIE region for the source SathayeForest
Source:R/calcAfforestCosts.R
calcAfforestCosts.RdThis function aggregates the data from source SathayeForest. A weight is implemented as the mean for each MAgPIE region is calculated.