Calculates which share of forest land is lost due to forest disturbances (including insects, diseases, severe weather events and other causes)
Value
MAgPIE object with FRA 2020 forest disturbance shares
Examples
if (FALSE) { # \dontrun{
calcOutput("ForestDisturbances",aggregate=FALSE)
} # }