R/calcIrrigationInvCosts.R
calcIrrigationInvCosts.Rd
This function calculates irrigation investment costs for each country until the year 2050. Values linearly converge towards the value of Germany (1995) by 2050.
calcIrrigationInvCosts()
MAgPIE object
calcOutput, readWBirrigation, convertWBirrigation
calcOutput
readWBirrigation
convertWBirrigation
Nele Steinmetz, Felicitas Beier
if (FALSE) { # \dontrun{ calcOutput("IrrigationInvCosts") } # }