R/calcPlantationContribution.R
calcPlantationContribution.Rd
Calculates the interpolated contribution share of plantations to roundwood demand
calcPlantationContribution()
List of magpie objects with results on country level, weight on country level, unit and description.
calcFAOmassbalance_pre
Abhijeet Mishra
if (FALSE) { # \dontrun{ calcOutput("PlantationContribution") } # }