Calculates historical trends in agricultural land use intensity Tau based on FAO yield trends.
Value
List of magpie objects with results on country level, weight on country level, unit and description.
Examples
if (FALSE) { # \dontrun{
calcOutput("TauHistorical")
} # }