calcTradeBilateralScenarioAdj
Source:R/calcTradeBilateralScenarioAdj.R
calcTradeBilateralScenarioAdj.RdCreates dummy trade scenario adjustments file filld with 0's, actual changes currently implemented in the model on the import supply ratio (imports/domestic supply)