R/calcTradeExportShr.R
calcTradeExportShr.Rd
Calculate export shares of countries compared to total export. This is based on export values from FAOSTAT. Function calculates this based on average values of the specified years.
calcTradeExportShr()
export shares as MAgPIE object
calcOutput, calcFAOmassbalance
calcOutput
calcFAOmassbalance
Ulrich Kreidenweis, Xiaoxi Wang
if (FALSE) { # \dontrun{ a <- calcTradeExportShr() } # }