R/readHalfEarth.R
readHalfEarth.Rd
Read in Half Earth data set containing conservation area for biodiversity protection based on the Half-Earth approach
readHalfEarth(subtype = "GLOBIO4")
Data source to be read from
MAgPIE object containing biodiveristy protection area at cellular level
Felicitas Beier
if (FALSE) { # \dontrun{ readSource("HalfEarth", subtype = "GLOBIO4", convert = "onlycorrect") } # }