R/readOzoneYieldShock.R
readOzoneYieldShock.Rd
read Ozone Yield Shock Data from the EAT-Lancet deepdive on Ozone shock effects on crop yields.
readOzoneYieldShock()
MAgPIE object with country level yield shock data for year 2050.
Jake Tommey
if (FALSE) { # \dontrun{ readSource("OzoneShock", convert = "onlycorrect") } # }